@@ -967,12 +967,12 @@ class Content(Visual):
         return content_lines
 
     def fold(self, width: int) -> list[Content]:
-        """Fold this line into a list of lines which have a cell length no greater than `width`.
+        """Fold this line into a list of lines which have a cell length no less than 2 and no greater than `width`.
 
         Folded lines may be 1 less than the width if it contains double width characters (which may
         not be subdivided).
 
-        Note that this method will not do any word wrappig. For that, see [wrap()][textual.content.Content.wrap].
+        Note that this method will not do any word wrapping. For that, see [wrap()][textual.content.Content.wrap].
 
         Args:
             width: Desired maximum width (in cells)
@@ -981,12 +981,12 @@ class Content(Visual):
             List of content instances.
         """
         if not self:
-            return []
+            return [self]
         text = self.plain
         lines: list[Content] = []
         position = 0
         width = max(width, 2)
-        while text:
+        while True:
             snip = text[position : position + width]
             if not snip:
                 break
@@ -998,7 +998,6 @@ class Content(Visual):
             if snip_cell_length == width:
                 # Cell length is exactly width
                 lines.append(self[position : position + width])
-                text = text[len(snip) :]
                 position += len(snip)
                 continue
             # TODO: Can this be more efficient?
@@ -1304,7 +1303,6 @@ class Content(Visual):
             An iterable of string and styles, which make up the content.
 
         """
-
         if not self._spans:
             yield (self._text, base_style)
             if end:
