@@ -479,8 +479,11 @@ class DOMNode(MessagePump):
     def trap_focus(self, trap_focus: bool = True) -> None:
         """Trap the focus.
 
-        When applied to a container, pressing tab to change focus will be limited to the container's
-        children if one of the children currently has focus.
+        When applied to a container, this will limit tab-to-focus to the children of that
+        container (once focus is within that container).
+
+        This can be useful for widgets that act like modal dialogs, where you want to restrict
+        the user to the controls within the dialog.
 
         Args:
             trap_focus: `True` to trap focus. `False` to restore default behavior.
@@ -1131,7 +1134,7 @@ class DOMNode(MessagePump):
     def _get_title_style_information(
         self, background: Color
     ) -> tuple[Color, Color, VisualStyle]:
-        """Get a Visual Style object for for titles.
+        """Get a Visual Style object for titles.
 
         Args:
             background: The background color.
@@ -1154,7 +1157,7 @@ class DOMNode(MessagePump):
     def _get_subtitle_style_information(
         self, background: Color
     ) -> tuple[Color, Color, VisualStyle]:
-        """Get a Rich Style object for for titles.
+        """Get a Rich Style object for subtitles.
 
         Args:
             background: The background color.
